# HG changeset patch
# User Peter Kovacs <kpeter@inf.elte.hu>
# Date 1507384080 -7200
# Node ID d9f79b81ef6c6a4f96b5e7e35150775b099aac63
# Parent  c89884c1737b4b54e16d5c704a99f14df639d777
Change the default graph type of Vf2 and Vf2pp (#597)

diff --git a/lemon/vf2.h b/lemon/vf2.h
--- a/lemon/vf2.h
+++ b/lemon/vf2.h
@@ -94,9 +94,9 @@
   ///use cases.
   ///
   ///\tparam G1 The type of the graph to be embedded.
   ///The default type is \ref ListDigraph.
   ///\tparam G2 The type of the graph g1 will be embedded into.
   ///The default type is \ref ListDigraph.
   ///\tparam M The type of the NodeMap storing the mapping.
   ///By default, it is G1::NodeMap<G2::Node>
   ///\tparam NEQ A bool-valued binary functor determinining whether a node is
@@ -106,8 +106,8 @@
 #ifdef DOXYGEN
   template<class G1, class G2, class M, class NEQ >
 #else
-  template<class G1=ListDigraph,
-           class G2=ListDigraph,
+  template<class G1 = ListGraph,
+           class G2 = ListGraph,
            class M = typename G1::template NodeMap<G2::Node>,
            class NEQ = bits::vf2::AlwaysEq >
 #endif
@@ -94,9 +94,9 @@
   ///
   ///\tparam G1 The type of the graph to be embedded.
-  ///The default type is \ref ListDigraph.
+  ///The default type is \ref ListGraph.
   ///\tparam G2 The type of the graph g1 will be embedded into.
@@ -94,9 +94,9 @@
   ///\tparam G2 The type of the graph g1 will be embedded into.
-  ///The default type is \ref ListDigraph.
+  ///The default type is \ref ListGraph.
   ///\tparam M The type of the NodeMap storing the mapping.
   ///By default, it is G1::NodeMap<G2::Node>
diff --git a/lemon/vf2pp.h b/lemon/vf2pp.h
--- a/lemon/vf2pp.h
+++ b/lemon/vf2pp.h
@@ -76,9 +76,9 @@
   ///more convenient in most use cases.
   ///
   ///\tparam G1 The type of the graph to be embedded.
   ///The default type is \ref ListDigraph.
   ///\tparam G2 The type of the graph g1 will be embedded into.
   ///The default type is \ref ListDigraph.
   ///\tparam M The type of the NodeMap storing the mapping.
   ///By default, it is G1::NodeMap<G2::Node>
   ///\tparam M1 The type of the NodeMap storing the integer node labels of G1.
@@ -92,8 +92,8 @@
 #ifdef DOXYGEN
   template<class G1, class G2, class M, class M1, class M2 >
 #else
-  template<class G1=ListDigraph,
-           class G2=ListDigraph,
+  template<class G1 = ListGraph,
+           class G2 = ListGraph,
            class M = typename G1::template NodeMap<G2::Node>,
            class M1 = typename G1::template NodeMap<int>,
            class M2 = typename G2::template NodeMap<int> >
@@ -76,9 +76,9 @@
   ///
   ///\tparam G1 The type of the graph to be embedded.
-  ///The default type is \ref ListDigraph.
+  ///The default type is \ref ListGraph.
   ///\tparam G2 The type of the graph g1 will be embedded into.
@@ -76,9 +76,9 @@
   ///\tparam G2 The type of the graph g1 will be embedded into.
-  ///The default type is \ref ListDigraph.
+  ///The default type is \ref ListGraph.
   ///\tparam M The type of the NodeMap storing the mapping.
   ///By default, it is G1::NodeMap<G2::Node>
